@@ -22,6 +22,7 @@
 #include <QStandardPaths>
 #include <QStatusBar>
 #include <QTimer>
+#include <QActionGroup>
 
 #include <KActionCollection>
 #include <KConfigGroup>
@@ -32,9 +33,7 @@
 #include <KRecentFilesAction>
 #include <KSharedConfig>
 #include <KToolBarPopupAction>
-
-#include <KNS3/QtQuickDialogWrapper>
-
+#include <KNSWidgets/Action>
 #include "interpreter/errormsg.h"
 #include "interpreter/translator.h"
 
@@ -186,11 +185,14 @@ void MainWindow::setupActions()
 	recentFilesAction = dynamic_cast<KRecentFilesAction*>(actionCollection()->addAction(KStandardAction::OpenRecent,  QStringLiteral("file_recent"), editor, SLOT(openFile(QUrl))));
 	recentFilesAction->setStatusTip(i18n("Open a recently used file"));
 	recentFilesAction->setWhatsThis(i18n("Open Recent File: Open a recently used file"));
-	
-	a = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Get more examples..."), this);
-	actionCollection()->addAction(QStringLiteral("get_new_examples"), a);
-	a->setText(i18n("Get more examples..."));
-	connect(a, &QAction::triggered, this, &MainWindow::getNewExampleDialog);
+
+	auto knsa = new KNSWidgets::Action(i18n("Get more examples..."), QStringLiteral("kturtle.knsrc"), this);
+	actionCollection()->addAction(QStringLiteral("get_new_examples"), knsa);
+	connect(knsa, &KNSWidgets::Action::dialogFinished, this, [this] (const QList<KNSCore::Entry> &changedEntries) {
+		if (!changedEntries.isEmpty()) {
+			updateExamplesMenu();
+		}
+	});
 
 	a = actionCollection()->addAction(KStandardAction::Save,  QStringLiteral("file_save"), editor, SLOT(saveFile()));
 	a->setStatusTip(i18n("Save the current file to disk"));
@@ -667,10 +669,8 @@ void MainWindow::updateLanguagesMenu()
 void MainWindow::updateExamplesMenu()
 {
 	QAction * newExample;
-	QString actionName;
-	QList<QAction*> exampleList;
 	QActionGroup* exampleGroup = new QActionGroup (this);
-
+    QList<QAction*> exampleList;
     const auto exampleNames{Translator::instance()->exampleNames()};
     for (const QString &exampleName : exampleNames) {
 		newExample = new QAction (exampleName, this);
@@ -749,7 +749,6 @@ void MainWindow::updateOnCursorPositionChange()
 	statusBarPositionLabel->setText(i18n(" Line: %1 Column: %2 ", editor->row(), editor->col()));
 
 	Token* cursorToken = editor->currentToken();
-	QString desc;
 	if (cursorToken) {
 		QString look = cursorToken->look();
 		int cat = cursorToken->category();
@@ -1070,12 +1069,3 @@ void MainWindow::slotMessageDialog(const QString& text)
 	if(!currentlyRunningConsole)
 		run();
 }
-
-void MainWindow::getNewExampleDialog()
-{
-    KNS3::QtQuickDialogWrapper dialog(QStringLiteral("kturtle.knsrc"));
-    const QList<KNSCore::EntryInternal> entries = dialog.exec();
-    if ( entries.size() > 0 ){
-        updateExamplesMenu();
-    }
-}
